@@ -337,11 +337,11 @@ WHERE
             override = os.environ.get("SET_WEB_CONFIG_OVERRIDE", "")
             if len(override) != 0:
                 override += "."
-            config_path = f"nginx.${override}config"
+            config_path = f"nginx.{override}config"
             if not os.path.exists(config_path):
                 config_path = "www/" + config_path
                 if not os.path.exists(config_path):
-                    print("Could not find config file")
+                    print("Could not find config file '" + config_path + "'")
                     return
 
             new_data = open(config_path, "r").read()
@@ -357,11 +357,10 @@ WHERE
             for line in lines:
                 if line.strip().startswith('charset'):
                     in_section = True
-                    updated_lines.append(line)
                     continue  # Skip to the next iteration
                 elif line.startswith('}') and in_section:
                     # Append new data before the end marker when in a section
-                    updated_lines.append(new_data)
+                    updated_lines.append(new_data + "\n")
                     in_section = False
 
                 if not in_section or line.startswith('}'):
